==> estateplat-common-1.2.3-20190225.031126-225-sources.jar: cn/gtmap/estateplat/model/register/WwDjModel.java <==
package cn.gtmap.estateplat.model.register;

import cn.gtmap.estateplat.model.exchange.court.GxPeKzqq;
import cn.gtmap.estateplat.model.exchange.court.GxPeKzqqXm;
import cn.gtmap.estateplat.model.exchange.share.*;

import java.io.Serializable;
import java.util.List;

/**
 * 共享外网申请信息表.
 */
public class WwDjModel implements Serializable {
    private List<GxWwSqxxFjxx> gxWwSqxxFjxxList;
    private List<GxWwSqxxClxx> gxWwSqxxClxxList;
    private List<GxWwSqxx> gxWwSqxxList;
    private List<GxWwSqxxQlr> gxWwSqxxQlrList;
    private List<GxWwSqxm> gxWwSqxmList;
    private List<GxWwYyxx> gxWwYyxxList;
    private List<GxPeKzqq> gxPeKzqqList; //法院查控
    private List<GxPeKzqqXm> gxPeKzqqXmList; //法院查控项目

    public List<GxWwSqxxFjxx> getGxWwSqxxFjxxList() {
        return gxWwSqxxFjxxList;
    }

    public void setGxWwSqxxFjxxList(List<GxWwSqxxFjxx> gxWwSqxxFjxxList) {
        this.gxWwSqxxFjxxList = gxWwSqxxFjxxList;
    }

    public List<GxWwSqxxClxx> getGxWwSqxxClxxList() {
        return gxWwSqxxClxxList;
    }

    public void setGxWwSqxxClxxList(List<GxWwSqxxClxx> gxWwSqxxClxxList) {
        this.gxWwSqxxClxxList = gxWwSqxxClxxList;
    }

    public List<GxWwSqxx> getGxWwSqxxList() {
        return gxWwSqxxList;
    }

    public void setGxWwSqxxList(List<GxWwSqxx> gxWwSqxxList) {
        this.gxWwSqxxList = gxWwSqxxList;
    }

    public List<GxWwSqxxQlr> getGxWwSqxxQlrList() {
        return gxWwSqxxQlrList;
    }

    public void setGxWwSqxxQlrList(List<GxWwSqxxQlr> gxWwSqxxQlrList) {
        this.gxWwSqxxQlrList = gxWwSqxxQlrList;
    }

    public List<GxWwSqxm> getGxWwSqxmList() {
        return gxWwSqxmList;
    }

    public void setGxWwSqxmList(List<GxWwSqxm> gxWwSqxmList) {
        this.gxWwSqxmList = gxWwSqxmList;
    }

    public List<GxWwYyxx> getGxWwYyxxList() {
        return gxWwYyxxList;
    }

    public void setGxWwYyxxList(List<GxWwYyxx> gxWwYyxxList) {
        this.gxWwYyxxList = gxWwYyxxList;
    }

    public List<GxPeKzqq> getGxPeKzqqList() {
        return gxPeKzqqList;
    }

    public void setGxPeKzqqList(List<GxPeKzqq> gxPeKzqqList) {
        this.gxPeKzqqList = gxPeKzqqList;
    }

    public List<GxPeKzqqXm> getGxPeKzqqXmList() {
        return gxPeKzqqXmList;
    }

    public void setGxPeKzqqXmList(List<GxPeKzqqXm> gxPeKzqqXmList) {
        this.gxPeKzqqXmList = gxPeKzqqXmList;
    }
}

==> estateplat-common-1.2.4-20210824.090210-853-sources.jar: cn/gtmap/estateplat/model/register/WwDjModel.java <==
package cn.gtmap.estateplat.model.register;

import cn.gtmap.estateplat.model.exchange.court.GxPeKzqq;
import cn.gtmap.estateplat.model.exchange.court.GxPeKzqqXm;
import cn.gtmap.estateplat.model.exchange.share.*;

import java.io.Serializable;
import java.util.List;

/**
 * 共享外网申请信息表.
 */
public class WwDjModel implements Serializable {
    private List<GxWwSqxxFjxx> gxWwSqxxFjxxList;
    private List<GxWwSqxxClxx> gxWwSqxxClxxList;
    private List<GxWwSqxx> gxWwSqxxList;
    private List<GxWwSqxxQlr> gxWwSqxxQlrList;
    private List<GxWwSqxm> gxWwSqxmList;
    private List<GxWwYyxx> gxWwYyxxList;
    private List<GxPeKzqq> gxPeKzqqList; //法院查控
    private List<GxPeKzqqXm> gxPeKzqqXmList; //法院查控项目
    private String sfyz;//是否验证

    public String getSfyz() {
        return sfyz;
    }

    public void setSfyz(String sfyz) {
        this.sfyz = sfyz;
    }

    public List<GxWwSqxxFjxx> getGxWwSqxxFjxxList() {
        return gxWwSqxxFjxxList;
    }

    public void setGxWwSqxxFjxxList(List<GxWwSqxxFjxx> gxWwSqxxFjxxList) {
        this.gxWwSqxxFjxxList = gxWwSqxxFjxxList;
    }

    public List<GxWwSqxxClxx> getGxWwSqxxClxxList() {
        return gxWwSqxxClxxList;
    }

    public void setGxWwSqxxClxxList(List<GxWwSqxxClxx> gxWwSqxxClxxList) {
        this.gxWwSqxxClxxList = gxWwSqxxClxxList;
    }

    public List<GxWwSqxx> getGxWwSqxxList() {
        return gxWwSqxxList;
    }

    public void setGxWwSqxxList(List<GxWwSqxx> gxWwSqxxList) {
        this.gxWwSqxxList = gxWwSqxxList;
    }

    public List<GxWwSqxxQlr> getGxWwSqxxQlrList() {
        return gxWwSqxxQlrList;
    }

    public void setGxWwSqxxQlrList(List<GxWwSqxxQlr> gxWwSqxxQlrList) {
        this.gxWwSqxxQlrList = gxWwSqxxQlrList;
    }

    public List<GxWwSqxm> getGxWwSqxmList() {
        return gxWwSqxmList;
    }

    public void setGxWwSqxmList(List<GxWwSqxm> gxWwSqxmList) {
        this.gxWwSqxmList = gxWwSqxmList;
    }

    public List<GxWwYyxx> getGxWwYyxxList() {
        return gxWwYyxxList;
    }

    public void setGxWwYyxxList(List<GxWwYyxx> gxWwYyxxList) {
        this.gxWwYyxxList = gxWwYyxxList;
    }

    public List<GxPeKzqq> getGxPeKzqqList() {
        return gxPeKzqqList;
    }

    public void setGxPeKzqqList(List<GxPeKzqq> gxPeKzqqList) {
        this.gxPeKzqqList = gxPeKzqqList;
    }

    public List<GxPeKzqqXm> getGxPeKzqqXmList() {
        return gxPeKzqqXmList;
    }

    public void setGxPeKzqqXmList(List<GxPeKzqqXm> gxPeKzqqXmList) {
        this.gxPeKzqqXmList = gxPeKzqqXmList;
    }
}
